==> haskell-concurrent-output-1.7.3-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-concurrent-output/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.7.3
id: concurrent-output-1.7.3-4422c3eeccd666690a04725dab779c50
key: concu_JbsTditQa1PHV6qSXL1ZYZ
license: BSD2
copyright: 2015 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
author: Joey Hess, Joachim Breitner
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/concurrent-output-1.7.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/concurrent-output-1.7.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/concurrent-output-1.7.3
hs-libraries: HSconcurrent-output-1.7.3-JbsTditQa1PHV6qSXL1ZYZ
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    terminal-size-0.3.2.1-bd07744e217c7dfc314ba4633ffee89d
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.7.4-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-concurrent-output/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.7.4
id: concurrent-output-1.7.4-f9691346a71b8edc8569215c754d5bdc
key: concu_L0G7AjnHel5Iot3N2TvIME
license: BSD2
copyright: 2015 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
author: Joey Hess, Joachim Breitner
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/concurrent-output-1.7.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/concurrent-output-1.7.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/concurrent-output-1.7.4
hs-libraries: HSconcurrent-output-1.7.4-L0G7AjnHel5Iot3N2TvIME
depends:
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    terminal-size-0.3.2.1-bd07744e217c7dfc314ba4633ffee89d
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
